/**
 * 
 * AiCiA - Android IRC Client
 * 
 * Copyright (C)2010 GORRY.
 * 
 */

package net.gorry.aicia;

import android.content.Context;
import android.content.SharedPreferences;
import android.util.Log;

/**
 * 
 * IRCサーバ設定の読み書き処理
 * 
 * @author GORRY
 *
 */
public class IRCServerConfig {
	private static final String TAG = "IRCServerConfig";
	private static final boolean V = false;

	private final Context me;

	/** サーバ設定名 */
	public String mServerName;

	/** 接続ホスト名 */
	public String mHost;

	/** 接続ポート番号 */
	public int mPort;

	/** 接続パスワード */
	public String mPass;

	/** 初期nick */
	public String mNick;

	/** ユーザー名 */
	public String mUsername;

	/** ユーザー実名 */
	public String mRealname;

	/** 文字列エンコーディング */
	public String mEncoding;

	/** SSL接続するならtrue */
	public boolean mUseSsl;

	/** メインメニューの[Connect]ボタンで接続するならtrue */
	public boolean mAutoConnect;

	/** 切断時に自動再接続を行うならtrue */
	public boolean mAutoReconnect;

	/** TweetIRCGateway(TIG)用オプションを使うならtrue */
	public boolean mForTIG;

	/** 初期接続チャンネル名 */
	public String mChannel;

	/** アラートキーワード */
	public String mAlertKeywords;

	/**
	 * コンストラクタ
	 * @param context コンテキスト
	 */
	public IRCServerConfig(final Context context) {
		if (V) Log.v(TAG, "IRCServerConfig()");
		me = context;
	}

	/**
	 * 設定読み込み
	 * @param configId サーバ設定ID
	 */
	public void loadConfig(final int configId) {
		if (V) Log.v(TAG, "loadConfig()");
		final String id = String.valueOf(configId);
		final SharedPreferences pref = me.getSharedPreferences("ircserver", 0);
		mServerName = pref.getString(id + ":servername", "");
		mHost = pref.getString(id + ":host", "");
		mPort = pref.getInt(id + ":port", 6667);
		mPass = pref.getString(id + ":pass", "");
		mNick = pref.getString(id + ":nick", "");
		mUsername = pref.getString(id + ":username", "");
		mRealname = pref.getString(id + ":realname", "");
		mEncoding = pref.getString(id + ":encoding", "ISO-2022-JP");
		mUseSsl = pref.getBoolean(id + ":usessl", false);
		mAutoConnect = pref.getBoolean(id + ":autoconnect", true);
		mAutoReconnect = pref.getBoolean(id + ":autoreconnect", true);
		mForTIG = pref.getBoolean(id + ":fortig", false);
		mChannel = pref.getString(id + ":channel", "");
		mAlertKeywords = pref.getString(id + ":alertkeywords", "");
	}

	/**
	 * 設定をコピー
	 * @param from コピー元
	 */
	public void copy(final IRCServerConfig from) {
		if (V) Log.v(TAG, "copyConfig()");
		mServerName = new String(from.mServerName);
		mHost = new String(from.mHost);
		mPort = from.mPort;
		mPass = new String(from.mPass);
		mNick = new String(from.mNick);
		mUsername = new String(from.mUsername);
		mRealname = new String(from.mRealname);
		mEncoding = new String(from.mEncoding);
		mUseSsl = from.mUseSsl;
		mAutoConnect = from.mAutoConnect;
		mAutoReconnect = from.mAutoReconnect;
		mForTIG = from.mForTIG;
		mChannel = new String(from.mChannel);
		mAlertKeywords = new String(from.mAlertKeywords);
	}

	/**
	 * 設定を比較
	 * @param from コピー元
	 * @return 同じならtrue
	 */
	public boolean compare(final IRCServerConfig from) {
		if (V) Log.v(TAG, "copyConfig()");
		if (!mServerName.equals(from.mServerName)) return false;
		if (!mHost.equals(from.mHost)) return false;
		if (mPort != from.mPort) return false;
		if (!mPass.equals(from.mPass)) return false;
		if (!mNick.equals(from.mNick)) return false;
		if (!mUsername.equals(from.mUsername)) return false;
		if (!mRealname.equals(from.mRealname)) return false;
		if (!mEncoding.equals(from.mEncoding)) return false;
		if (mUseSsl != from.mUseSsl) return false;
		if (mAutoConnect != from.mAutoConnect) return false;
		if (mAutoReconnect != from.mAutoReconnect) return false;
		if (mForTIG != from.mForTIG) return false;
		if (!mChannel.equals(from.mChannel)) return false;
		if (!mAlertKeywords.equals(from.mAlertKeywords)) return false;
		return true;
	}

	/**
	 * 設定保存
	 * @param configId サーバ設定ID
	 */
	public void saveConfig(final int configId) {
		if (V) Log.v(TAG, "saveConfig()");
		final SharedPreferences pref = me.getSharedPreferences("ircserver", 0);
		final String id = String.valueOf(configId);
		final SharedPreferences.Editor editor = pref.edit();
		editor.putString(id + ":servername", mServerName);
		editor.putString(id + ":host", mHost);
		editor.putInt(id + ":port", mPort);
		editor.putString(id + ":pass", mPass);
		editor.putString(id + ":nick", mNick);
		editor.putString(id + ":username", mUsername);
		editor.putString(id + ":realname", mRealname);
		editor.putString(id + ":encoding", mEncoding);
		editor.putBoolean(id + ":usessl", mUseSsl);
		editor.putBoolean(id + ":autoconnect", mAutoConnect);
		editor.putBoolean(id + ":autoreconnect", mAutoReconnect);
		editor.putBoolean(id + ":fortig", mForTIG);
		editor.putString(id + ":channel", mChannel);
		editor.putString(id + ":alertkeywords", mAlertKeywords);
		editor.commit();
	}

	/**
	 * 設定消去
	 * @param configId サーバ設定ID
	 */
	public void deleteConfig(final int configId) {
		if (V) Log.v(TAG, "deleteConfig()");
		final SharedPreferences pref = me.getSharedPreferences("ircserver", 0);
		final String id = String.valueOf(configId);
		final SharedPreferences.Editor editor = pref.edit();
		editor.remove(id + ":servername");
		editor.remove(id + ":host");
		editor.remove(id + ":port");
		editor.remove(id + ":pass");
		editor.remove(id + ":nick");
		editor.remove(id + ":username");
		editor.remove(id + ":realname");
		editor.remove(id + ":encoding");
		editor.remove(id + ":usessl");
		editor.remove(id + ":autoconnect");
		editor.remove(id + ":autoreconnect");
		editor.remove(id + ":fortig");
		editor.remove(id + ":channel");
		editor.remove(id + ":alertkeywords");
		editor.commit();
	}
}
